==> five-bells-shared-22.0.1.tgz: package/integration-test/ilp-kit/src/redux/actionTypes.js <==
export const UPDATE_LOCATION_COMPLETE = 'UPDATE_LOCATION_COMPLETE'
export const SET_ADVANCED_MODE = 'SET_ADVANCED_MODE'

export const AUTH_LOAD = 'AUTH_LOAD_PENDING'
export const AUTH_LOAD_SUCCESS = 'AUTH_LOAD_SUCCESS'
export const AUTH_LOAD_FAIL = 'AUTH_LOAD_FAIL'

export const AUTH_SAVE = 'AUTH_SAVE_PENDING'
export const AUTH_SAVE_SUCCESS = 'AUTH_SAVE_SUCCESS'
export const AUTH_SAVE_FAIL = 'AUTH_SAVE_FAIL'

export const AUTH_UPDATE_PIC = 'AUTH_UPDATE_PIC'

export const EMAIL_VERIFICATION = 'EMAIL_VERIFICATION_PENDING'
export const EMAIL_VERIFICATION_SUCCESS = 'EMAIL_VERIFICATION_SUCCESS'
export const EMAIL_VERIFICATION_FAIL = 'EMAIL_VERIFICATION_FAIL'

export const EMAIL_VERIFICATION_RESEND = 'EMAIL_VERIFICATION_RESEND_PENDING'
export const EMAIL_VERIFICATION_RESEND_SUCCESS = 'EMAIL_VERIFICATION_RESEND_SUCCESS'
export const EMAIL_VERIFICATION_RESEND_FAIL = 'EMAIL_VERIFICATION_RESEND_FAIL'

export const LOAD_CONFIG = 'LOAD_CONFIG_PENDING'
export const LOAD_CONFIG_SUCCESS = 'LOAD_CONFIG_SUCCESS'
export const LOAD_CONFIG_FAIL = 'LOAD_CONFIG_FAIL'

export const LOGIN = 'LOGIN_PENDING'
export const LOGIN_SUCCESS = 'LOGIN_SUCCESS'
export const LOGIN_FAIL = 'LOGIN_FAIL'

export const REGISTER = 'REGISTER_PENDING'
export const REGISTER_SUCCESS = 'REGISTER_SUCCESS'
export const REGISTER_FAIL = 'REGISTER_FAIL'

export const FORGOT_PASSWORD = 'FORGOT_PASSWORD_PENDING'
export const FORGOT_PASSWORD_SUCCESS = 'FORGOT_PASSWORD_SUCCESS'
export const FORGOT_PASSWORD_FAIL = 'FORGOT_PASSWORD_FAIL'

export const CHANGE_PASSWORD = 'CHANGE_PASSWORD_PENDING'
export const CHANGE_PASSWORD_SUCCESS = 'CHANGE_PASSWORD_SUCCESS'
export const CHANGE_PASSWORD_FAIL = 'CHANGE_PASSWORD_FAIL'

export const LOGOUT = 'LOGOUT_PENDING'
export const LOGOUT_SUCCESS = 'LOGOUT_SUCCESS'
export const LOGOUT_FAIL = 'LOGOUT_FAIL'

export const UPDATE_BALANCE = 'UPDATE_BALANCE'

export const RELOADING = 'RELOADING_PENDING'
export const RELOAD_SUCCESS = 'RELOAD_SUCCESS'
export const RELOAD_FAIL = 'RELOAD_FAIL'

export const DESTROY = 'DESTROY'

export const PAYMENT_JSON_LOADING = 'PAYMENT_JSON_LOADING'
export const PAYMENT_JSON_SUCCESS = 'PAYMENT_JSON_SUCCESS'
export const PAYMENT_JSON_FAIL = 'PAYMENT_JSON_FAIL'
export const PAYMENT_JSON_SHOW = 'PAYMENT_JSON_SHOW'
export const PAYMENT_JSON_HIDE = 'PAYMENT_JSON_HIDE'

export const WS_PAYMENT = 'WS_PAYMENT'

export const SEND = 'SEND_PENDING'
export const SEND_SUCCESS = 'SEND_SUCCESS'
export const SEND_FAIL = 'SEND_FAIL'
export const SEND_RESET = 'SEND_RESET'

export const DESTINATION_CHANGE = 'DESTINATION_CHANGE_PENDING'
export const DESTINATION_CHANGE_SUCCESS = 'DESTINATION_CHANGE_SUCCESS'
export const DESTINATION_CHANGE_FAIL = 'DESTINATION_CHANGE_FAIL'
export const DESTINATION_RESET = 'DESTINATION_RESET'

export const AMOUNTS_CHANGE = 'AMOUNTS_CHANGE'

export const REQUEST_QUOTE = 'REQUEST_QUOTE_PENDING'
export const REQUEST_QUOTE_SUCCESS = 'REQUEST_QUOTE_SUCCESS'
export const REQUEST_QUOTE_FAIL = 'REQUEST_QUOTE_FAIL'

export const LOAD_TRANSFERS = 'LOAD_TRANSFERS_PENDING'
export const LOAD_TRANSFERS_SUCCESS = 'LOAD_TRANSFERS_SUCCESS'
export const LOAD_TRANSFERS_FAIL = 'LOAD_TRANSFERS_FAIL'

export const LOAD_STATS = 'LOAD_STATS_PENDING'
export const LOAD_STATS_SUCCESS = 'LOAD_STATS_SUCCESS'
export const LOAD_STATS_FAIL = 'LOAD_STATS_FAIL'

// Invites
export const LOAD_INVITES = 'LOAD_INVITES_PENDING'
export const LOAD_INVITES_SUCCESS = 'LOAD_INVITES_SUCCESS'
export const LOAD_INVITES_FAIL = 'LOAD_INVITES_FAIL'

export const LOAD_INVITE = 'LOAD_INVITE_PENDING'
export const LOAD_INVITE_SUCCESS = 'LOAD_INVITE_SUCCESS'
export const LOAD_INVITE_FAIL = 'LOAD_INVITE_FAIL'

export const CREATE_INVITE = 'CREATE_INVITE_PENDING'
export const CREATE_INVITE_SUCCESS = 'CREATE_INVITE_SUCCESS'
export const CREATE_INVITE_FAIL = 'CREATE_INVITE_FAIL'

export const REMOVE_INVITE = 'REMOVE_INVITE_PENDING'
export const REMOVE_INVITE_SUCCESS = 'REMOVE_INVITE_SUCCESS'
export const REMOVE_INVITE_FAIL = 'REMOVE_INVITE_FAIL'

// Peers
export const LOAD_PEERS = 'LOAD_PEERS_PENDING'
export const LOAD_PEERS_SUCCESS = 'LOAD_PEERS_SUCCESS'
export const LOAD_PEERS_FAIL = 'LOAD_PEERS_FAIL'

export const GET_PEER = 'GET_PEER_PENDING'
export const GET_PEER_SUCCESS = 'GET_PEER_SUCCESS'
export const GET_PEER_FAIL = 'GET_PEER_FAIL'

export const ADD_PEER = 'ADD_PEER_PENDING'
export const ADD_PEER_SUCCESS = 'ADD_PEER_SUCCESS'
export const ADD_PEER_FAIL = 'ADD_PEER_FAIL'

export const UPDATE_PEER = 'UPDATE_PEER_PENDING'
export const UPDATE_PEER_SUCCESS = 'UPDATE_PEER_SUCCESS'
export const UPDATE_PEER_FAIL = 'UPDATE_PEER_FAIL'

export const REMOVE_PEER = 'REMOVE_PEER_PENDING'
export const REMOVE_PEER_SUCCESS = 'REMOVE_PEER_SUCCESS'
export const REMOVE_PEER_FAIL = 'REMOVE_PEER_FAIL'

export const LOAD_PEER_SETTLEMENT_METHODS = 'LOAD_PEER_SETTLEMENT_METHODS_PENDING'
export const LOAD_PEER_SETTLEMENT_METHODS_SUCCESS = 'LOAD_PEER_SETTLEMENT_METHODS_SUCCESS'
export const LOAD_PEER_SETTLEMENT_METHODS_FAIL = 'LOAD_PEER_SETTLEMENT_METHODS_FAIL'

// Settlement Methods
export const LOAD_SETTLEMENT_METHODS = 'LOAD_SETTLEMENT_METHODS_PENDING'
export const LOAD_SETTLEMENT_METHODS_SUCCESS = 'LOAD_SETTLEMENT_METHODS_SUCCESS'
export const LOAD_SETTLEMENT_METHODS_FAIL = 'LOAD_SETTLEMENT_METHODS_FAIL'

export const ADD_SETTLEMENT_METHOD = 'ADD_SETTLEMENT_METHOD_PENDING'
export const ADD_SETTLEMENT_METHOD_SUCCESS = 'ADD_SETTLEMENT_METHOD_SUCCESS'
export const ADD_SETTLEMENT_METHOD_FAIL = 'ADD_SETTLEMENT_METHOD_FAIL'

export const UPDATE_SETTLEMENT_METHOD = 'UPDATE_SETTLEMENT_METHOD_PENDING'
export const UPDATE_SETTLEMENT_METHOD_SUCCESS = 'UPDATE_SETTLEMENT_METHOD_SUCCESS'
export const UPDATE_SETTLEMENT_METHOD_FAIL = 'UPDATE_SETTLEMENT_METHOD_FAIL'

export const REMOVE_SETTLEMENT_METHOD = 'REMOVE_SETTLEMENT_METHOD_PENDING'
export const REMOVE_SETTLEMENT_METHOD_SUCCESS = 'REMOVE_SETTLEMENT_METHOD_SUCCESS'
export const REMOVE_SETTLEMENT_METHOD_FAIL = 'REMOVE_SETTLEMENT_METHOD_FAIL'

export const UPDATE_SETTLEMENT_METHOD_PIC = 'UPDATE_SETTLEMENT_METHOD_PIC_PENDING'
export const UPDATE_SETTLEMENT_METHOD_PIC_SUCCESS = 'UPDATE_SETTLEMENT_METHOD_PIC_SUCCESS'
export const UPDATE_SETTLEMENT_METHOD_PIC_FAIL = 'UPDATE_SETTLEMENT_METHOD_PIC_FAIL'

// Settlements
export const GET_SETTLEMENT = 'GET_SETTLEMENT'
export const GET_SETTLEMENT_SUCCESS = 'GET_SETTLEMENT_SUCCESS'
export const GET_SETTLEMENT_FAIL = 'GET_SETTLEMENT_FAIL'

export const GET_DESTINATION = 'GET_DESTINATION'
export const GET_DESTINATION_SUCCESS = 'GET_DESTINATION_SUCCESS'
export const GET_DESTINATION_FAIL = 'GET_DESTINATION_FAIL'

export const SETTLE = 'SETTLE_PENDING'
export const SETTLE_SUCCESS = 'SETTLE_SUCCESS'
export const SETTLE_FAIL = 'SETTLE_FAIL'

// Users
export const LOAD_USERS = 'LOAD_USERS_PENDING'
export const LOAD_USERS_SUCCESS = 'LOAD_USERS_SUCCESS'
export const LOAD_USERS_FAIL = 'LOAD_USERS_FAIL'

==> five-bells-shared-24.0.0.tgz: package/integration-test/ilp-kit/src/redux/actionTypes.js <==
export const UPDATE_LOCATION_COMPLETE = 'UPDATE_LOCATION_COMPLETE'
export const SET_ADVANCED_MODE = 'SET_ADVANCED_MODE'

export const AUTH_LOAD = 'AUTH_LOAD_PENDING'
export const AUTH_LOAD_SUCCESS = 'AUTH_LOAD_SUCCESS'
export const AUTH_LOAD_FAIL = 'AUTH_LOAD_FAIL'

export const AUTH_SAVE = 'AUTH_SAVE_PENDING'
export const AUTH_SAVE_SUCCESS = 'AUTH_SAVE_SUCCESS'
export const AUTH_SAVE_FAIL = 'AUTH_SAVE_FAIL'

export const AUTH_UPDATE_PIC = 'AUTH_UPDATE_PIC'

export const EMAIL_VERIFICATION = 'EMAIL_VERIFICATION_PENDING'
export const EMAIL_VERIFICATION_SUCCESS = 'EMAIL_VERIFICATION_SUCCESS'
export const EMAIL_VERIFICATION_FAIL = 'EMAIL_VERIFICATION_FAIL'

export const EMAIL_VERIFICATION_RESEND = 'EMAIL_VERIFICATION_RESEND_PENDING'
export const EMAIL_VERIFICATION_RESEND_SUCCESS = 'EMAIL_VERIFICATION_RESEND_SUCCESS'
export const EMAIL_VERIFICATION_RESEND_FAIL = 'EMAIL_VERIFICATION_RESEND_FAIL'

export const LOAD_CONFIG = 'LOAD_CONFIG_PENDING'
export const LOAD_CONFIG_SUCCESS = 'LOAD_CONFIG_SUCCESS'
export const LOAD_CONFIG_FAIL = 'LOAD_CONFIG_FAIL'

export const LOGIN = 'LOGIN_PENDING'
export const LOGIN_SUCCESS = 'LOGIN_SUCCESS'
export const LOGIN_FAIL = 'LOGIN_FAIL'

export const REGISTER = 'REGISTER_PENDING'
export const REGISTER_SUCCESS = 'REGISTER_SUCCESS'
export const REGISTER_FAIL = 'REGISTER_FAIL'

export const FORGOT_PASSWORD = 'FORGOT_PASSWORD_PENDING'
export const FORGOT_PASSWORD_SUCCESS = 'FORGOT_PASSWORD_SUCCESS'
export const FORGOT_PASSWORD_FAIL = 'FORGOT_PASSWORD_FAIL'

export const CHANGE_PASSWORD = 'CHANGE_PASSWORD_PENDING'
export const CHANGE_PASSWORD_SUCCESS = 'CHANGE_PASSWORD_SUCCESS'
export const CHANGE_PASSWORD_FAIL = 'CHANGE_PASSWORD_FAIL'

export const LOGOUT = 'LOGOUT_PENDING'
export const LOGOUT_SUCCESS = 'LOGOUT_SUCCESS'
export const LOGOUT_FAIL = 'LOGOUT_FAIL'

export const UPDATE_BALANCE = 'UPDATE_BALANCE'

export const RELOADING = 'RELOADING_PENDING'
export const RELOAD_SUCCESS = 'RELOAD_SUCCESS'
export const RELOAD_FAIL = 'RELOAD_FAIL'

export const DESTROY = 'DESTROY'

export const PAYMENT_JSON_LOADING = 'PAYMENT_JSON_LOADING'
export const PAYMENT_JSON_SUCCESS = 'PAYMENT_JSON_SUCCESS'
export const PAYMENT_JSON_FAIL = 'PAYMENT_JSON_FAIL'
export const PAYMENT_JSON_SHOW = 'PAYMENT_JSON_SHOW'
export const PAYMENT_JSON_HIDE = 'PAYMENT_JSON_HIDE'

export const WS_ACTIVITY = 'WS_ACTIVITY'

export const SEND = 'SEND_PENDING'
export const SEND_SUCCESS = 'SEND_SUCCESS'
export const SEND_FAIL = 'SEND_FAIL'
export const SEND_RESET = 'SEND_RESET'

export const DESTINATION_CHANGE = 'DESTINATION_CHANGE_PENDING'
export const DESTINATION_CHANGE_SUCCESS = 'DESTINATION_CHANGE_SUCCESS'
export const DESTINATION_CHANGE_FAIL = 'DESTINATION_CHANGE_FAIL'
export const DESTINATION_RESET = 'DESTINATION_RESET'

export const AMOUNTS_CHANGE = 'AMOUNTS_CHANGE'

export const REQUEST_QUOTE = 'REQUEST_QUOTE_PENDING'
export const REQUEST_QUOTE_SUCCESS = 'REQUEST_QUOTE_SUCCESS'
export const REQUEST_QUOTE_FAIL = 'REQUEST_QUOTE_FAIL'

export const LOAD_STATS = 'LOAD_STATS_PENDING'
export const LOAD_STATS_SUCCESS = 'LOAD_STATS_SUCCESS'
export const LOAD_STATS_FAIL = 'LOAD_STATS_FAIL'

// Invites
export const LOAD_INVITES = 'LOAD_INVITES_PENDING'
export const LOAD_INVITES_SUCCESS = 'LOAD_INVITES_SUCCESS'
export const LOAD_INVITES_FAIL = 'LOAD_INVITES_FAIL'

export const LOAD_INVITE = 'LOAD_INVITE_PENDING'
export const LOAD_INVITE_SUCCESS = 'LOAD_INVITE_SUCCESS'
export const LOAD_INVITE_FAIL = 'LOAD_INVITE_FAIL'

export const CREATE_INVITE = 'CREATE_INVITE_PENDING'
export const CREATE_INVITE_SUCCESS = 'CREATE_INVITE_SUCCESS'
export const CREATE_INVITE_FAIL = 'CREATE_INVITE_FAIL'

export const REMOVE_INVITE = 'REMOVE_INVITE_PENDING'
export const REMOVE_INVITE_SUCCESS = 'REMOVE_INVITE_SUCCESS'
export const REMOVE_INVITE_FAIL = 'REMOVE_INVITE_FAIL'

// Peers
export const LOAD_PEERS = 'LOAD_PEERS_PENDING'
export const LOAD_PEERS_SUCCESS = 'LOAD_PEERS_SUCCESS'
export const LOAD_PEERS_FAIL = 'LOAD_PEERS_FAIL'

export const GET_PEER = 'GET_PEER_PENDING'
export const GET_PEER_SUCCESS = 'GET_PEER_SUCCESS'
export const GET_PEER_FAIL = 'GET_PEER_FAIL'

export const ADD_PEER = 'ADD_PEER_PENDING'
export const ADD_PEER_SUCCESS = 'ADD_PEER_SUCCESS'
export const ADD_PEER_FAIL = 'ADD_PEER_FAIL'

export const UPDATE_PEER = 'UPDATE_PEER_PENDING'
export const UPDATE_PEER_SUCCESS = 'UPDATE_PEER_SUCCESS'
export const UPDATE_PEER_FAIL = 'UPDATE_PEER_FAIL'

export const REMOVE_PEER = 'REMOVE_PEER_PENDING'
export const REMOVE_PEER_SUCCESS = 'REMOVE_PEER_SUCCESS'
export const REMOVE_PEER_FAIL = 'REMOVE_PEER_FAIL'

export const LOAD_PEER_SETTLEMENT_METHODS = 'LOAD_PEER_SETTLEMENT_METHODS_PENDING'
export const LOAD_PEER_SETTLEMENT_METHODS_SUCCESS = 'LOAD_PEER_SETTLEMENT_METHODS_SUCCESS'
export const LOAD_PEER_SETTLEMENT_METHODS_FAIL = 'LOAD_PEER_SETTLEMENT_METHODS_FAIL'

// Settlement Methods
export const LOAD_SETTLEMENT_METHODS = 'LOAD_SETTLEMENT_METHODS_PENDING'
export const LOAD_SETTLEMENT_METHODS_SUCCESS = 'LOAD_SETTLEMENT_METHODS_SUCCESS'
export const LOAD_SETTLEMENT_METHODS_FAIL = 'LOAD_SETTLEMENT_METHODS_FAIL'

export const ADD_SETTLEMENT_METHOD = 'ADD_SETTLEMENT_METHOD_PENDING'
export const ADD_SETTLEMENT_METHOD_SUCCESS = 'ADD_SETTLEMENT_METHOD_SUCCESS'
export const ADD_SETTLEMENT_METHOD_FAIL = 'ADD_SETTLEMENT_METHOD_FAIL'

export const UPDATE_SETTLEMENT_METHOD = 'UPDATE_SETTLEMENT_METHOD_PENDING'
export const UPDATE_SETTLEMENT_METHOD_SUCCESS = 'UPDATE_SETTLEMENT_METHOD_SUCCESS'
export const UPDATE_SETTLEMENT_METHOD_FAIL = 'UPDATE_SETTLEMENT_METHOD_FAIL'

export const REMOVE_SETTLEMENT_METHOD = 'REMOVE_SETTLEMENT_METHOD_PENDING'
export const REMOVE_SETTLEMENT_METHOD_SUCCESS = 'REMOVE_SETTLEMENT_METHOD_SUCCESS'
export const REMOVE_SETTLEMENT_METHOD_FAIL = 'REMOVE_SETTLEMENT_METHOD_FAIL'

export const UPDATE_SETTLEMENT_METHOD_PIC = 'UPDATE_SETTLEMENT_METHOD_PIC_PENDING'
export const UPDATE_SETTLEMENT_METHOD_PIC_SUCCESS = 'UPDATE_SETTLEMENT_METHOD_PIC_SUCCESS'
export const UPDATE_SETTLEMENT_METHOD_PIC_FAIL = 'UPDATE_SETTLEMENT_METHOD_PIC_FAIL'

// Settlements
export const GET_SETTLEMENT = 'GET_SETTLEMENT'
export const GET_SETTLEMENT_SUCCESS = 'GET_SETTLEMENT_SUCCESS'
export const GET_SETTLEMENT_FAIL = 'GET_SETTLEMENT_FAIL'

export const GET_DESTINATION = 'GET_DESTINATION'
export const GET_DESTINATION_SUCCESS = 'GET_DESTINATION_SUCCESS'
export const GET_DESTINATION_FAIL = 'GET_DESTINATION_FAIL'

export const SETTLE = 'SETTLE_PENDING'
export const SETTLE_SUCCESS = 'SETTLE_SUCCESS'
export const SETTLE_FAIL = 'SETTLE_FAIL'

// Users
export const LOAD_USERS = 'LOAD_USERS_PENDING'
export const LOAD_USERS_SUCCESS = 'LOAD_USERS_SUCCESS'
export const LOAD_USERS_FAIL = 'LOAD_USERS_FAIL'

// Withdraw
export const WITHDRAW = 'WITHDRAW'
export const WITHDRAW_SUCCESS = 'WITHDRAW_SUCCESS'
export const WITHDRAW_FAIL = 'WITHDRAW_FAIL'

export const LOAD_WITHDRAWALS = 'LOAD_WITHDRAWALS'
export const LOAD_WITHDRAWALS_SUCCESS = 'LOAD_WITHDRAWALS_SUCCESS'
export const LOAD_WITHDRAWALS_FAIL = 'LOAD_WITHDRAWALS_FAIL'

export const UPDATE_WITHDRAWAL = 'UPDATE_WITHDRAWAL'
export const UPDATE_WITHDRAWAL_SUCCESS = 'UPDATE_WITHDRAWAL_SUCCESS'
export const UPDATE_WITHDRAWAL_FAIL = 'UPDATE_WITHDRAWAL_FAIL'
